@@ -4,10 +4,10 @@ import urwid
 import webbrowser
 
 from toot import __version__
-from toot.utils import format_content
-from .utils import highlight_hashtags, highlight_keys
-from .widgets import Button, EditBox, SelectableText
 from toot import api
+from toot.tui.utils import highlight_keys
+from toot.tui.widgets import Button, EditBox, SelectableText
+from toot.tui.richtext import html_to_widgets
 
 
 class StatusSource(urwid.Padding):
@@ -81,15 +81,15 @@ class StatusDeleteConfirmation(urwid.ListBox):
     signals = ["delete", "close"]
 
     def __init__(self, status):
-        yes = SelectableText("Yes, send it to heck")
-        no = SelectableText("No, I'll spare it for now")
+        def _delete(_):
+            self._emit("delete")
 
-        urwid.connect_signal(yes, "click", lambda *args: self._emit("delete"))
-        urwid.connect_signal(no, "click", lambda *args: self._emit("close"))
+        def _close(_):
+            self._emit("close")
 
         walker = urwid.SimpleFocusListWalker([
-            urwid.AttrWrap(yes, "", "blue_selected"),
-            urwid.AttrWrap(no, "", "blue_selected"),
+            Button("Yes, delete", on_press=_delete),
+            Button("No, cancel", on_press=_close),
         ])
         super().__init__(walker)
 
@@ -102,19 +102,22 @@ class GotoMenu(urwid.ListBox):
         "bookmark_timeline",
         "notification_timeline",
         "conversation_timeline",
+        "personal_timeline",
+        "list_timeline",
     ]
 
-    def __init__(self, user_timelines):
+    def __init__(self, user_timelines, user_lists):
         self.hash_edit = EditBox(caption="Hashtag: ")
+        self.message_widget = urwid.Text("")
 
-        actions = list(self.generate_actions(user_timelines))
+        actions = list(self.generate_actions(user_timelines, user_lists))
         walker = urwid.SimpleFocusListWalker(actions)
         super().__init__(walker)
 
     def get_hashtag(self):
-        return self.hash_edit.edit_text.strip()
+        return self.hash_edit.edit_text.strip().lstrip("#")
 
-    def generate_actions(self, user_timelines):
+    def generate_actions(self, user_timelines, user_lists):
         def _home(button):
             self._emit("home_timeline")
 
@@ -124,6 +127,9 @@ class GotoMenu(urwid.ListBox):
         def _global_public(button):
             self._emit("public_timeline", False)
 
+        def _personal(button):
+            self._emit("personal_timeline", False)
+
         def _bookmarks(button):
             self._emit("bookmark_timeline", False)
 
@@ -134,33 +140,51 @@ class GotoMenu(urwid.ListBox):
             self._emit("conversation_timeline", False)
 
         def _hashtag(local):
+            self.message_widget.set_text("")
             hashtag = self.get_hashtag()
             if hashtag:
                 self._emit("hashtag_timeline", hashtag, local)
             else:
-                self.set_focus(4)
+                self.message_widget.set_text(("warning", "Hashtag name required"))
 
         def mk_on_press_user_hashtag(tag, local):
             def on_press(btn):
                 self._emit("hashtag_timeline", tag, local)
             return on_press
 
+        def mk_on_press_user_list(list_item):
+            def on_press(btn):
+                self._emit("list_timeline", list_item)
+            return on_press
+
         yield Button("Home timeline", on_press=_home)
-
-        for tag, cfg in user_timelines.items():
-            is_local = cfg["local"]
-            yield Button("#{}".format(tag) + (" (local)" if is_local else ""),
-                         on_press=mk_on_press_user_hashtag(tag, is_local))
-
         yield Button("Local public timeline", on_press=_local_public)
         yield Button("Global public timeline", on_press=_global_public)
+        yield Button("Personal timeline", on_press=_personal)
         yield Button("Bookmarks", on_press=_bookmarks)
         yield Button("Notifications", on_press=_notifications)
         yield Button("Conversations", on_press=_conversations)
+
+        if len(user_timelines):
+            yield urwid.Divider()
+            yield urwid.Text(("bold", "Shortcuts:"))
+
+            # show all hashtag shortcuts
+            for tag, cfg in sorted(user_timelines.items()):
+                is_local = cfg["local"]
+                yield Button(f"#{tag}" + (" (local)" if is_local else ""),
+                     on_press=mk_on_press_user_hashtag(tag, is_local))
+
+        for list_item in user_lists:
+            yield Button(f"\N{clipboard}{list_item['title']}",
+                         on_press=mk_on_press_user_list(list_item))
+
         yield urwid.Divider()
         yield self.hash_edit
         yield Button("Local hashtag timeline", on_press=lambda x: _hashtag(True))
         yield Button("Public hashtag timeline", on_press=lambda x: _hashtag(False))
+        yield urwid.Divider()
+        yield self.message_widget
 
 
 class Help(urwid.Padding):
@@ -172,9 +196,9 @@ class Help(urwid.Padding):
 
     def generate_contents(self):
         def h(text):
-            return highlight_keys(text, "cyan")
+            return highlight_keys(text, "shortcut")
 
-        yield urwid.Text(("yellow_bold", "toot {}".format(__version__)))
+        yield urwid.Text(("bold", "toot {}".format(__version__)))
         yield urwid.Divider()
         yield urwid.Text(("bold", "General usage"))
         yield urwid.Divider()
@@ -187,9 +211,9 @@ class Help(urwid.Padding):
         yield urwid.Divider()
         yield urwid.Text(h("  [Q] - quit toot"))
         yield urwid.Text(h("  [G] - go to - switch timelines"))
-        yield urwid.Text(h("  [P] - save/unsave (pin) current timeline"))
+        yield urwid.Text(h("  [E] - save/unsave (pin) current timeline"))
         yield urwid.Text(h("  [,] - refresh current timeline"))
-        yield urwid.Text(h("  [H] - show this help"))
+        yield urwid.Text(h("  [?] - show this help"))
         yield urwid.Divider()
         yield urwid.Text(("bold", "Status keys"))
         yield urwid.Divider()
@@ -202,6 +226,7 @@ class Help(urwid.Padding):
         yield urwid.Text(h("  [N] - Translate status if possible (toggle)"))
         yield urwid.Text(h("  [R] - Reply to current status"))
         yield urwid.Text(h("  [S] - Show text marked as sensitive"))
+        yield urwid.Text(h("  [M] - Show status media"))
         yield urwid.Text(h("  [T] - Show status thread (replies)"))
         yield urwid.Text(h("  [L] - Show the status links"))
         yield urwid.Text(h("  [U] - Show the status data in JSON as received from the server"))
@@ -236,10 +261,10 @@ class Account(urwid.ListBox):
             yield Button("Cancel", on_press=cancel_action, user_data=self)
         else:
             if self.user.username == account["acct"]:
-                yield urwid.Text(("light gray", "This is your account"))
+                yield urwid.Text(("dim", "This is your account"))
             else:
                 if relationship['requested']:
-                    yield urwid.Text(("light gray", "< Follow request is pending >"))
+                    yield urwid.Text(("dim", "< Follow request is pending >"))
                 else:
                     yield Button("Unfollow" if relationship['following'] else "Follow",
                     on_press=confirm_action, user_data=self)
@@ -251,20 +276,22 @@ class Account(urwid.ListBox):
 
         yield urwid.Divider("─")
         yield urwid.Divider()
-        yield urwid.Text([('green', f"@{account['acct']}"), f"  {account['display_name']}"])
+        yield urwid.Text([("account", f"@{account['acct']}"), f"  {account['display_name']}"])
 
         if account["note"]:
             yield urwid.Divider()
-            for line in format_content(account["note"]):
-                yield urwid.Text(highlight_hashtags(line, followed_tags=set()))
+
+            widgetlist = html_to_widgets(account["note"])
+            for line in widgetlist:
+                yield (line)
 
         yield urwid.Divider()
-        yield urwid.Text(["ID: ", ("green", f"{account['id']}")])
-        yield urwid.Text(["Since: ", ("green", f"{account['created_at'][:10]}")])
+        yield urwid.Text(["ID: ", ("highlight", f"{account['id']}")])
+        yield urwid.Text(["Since: ", ("highlight", f"{account['created_at'][:10]}")])
         yield urwid.Divider()
 
         if account["bot"]:
-            yield urwid.Text([("green", "Bot \N{robot face}")])
+            yield urwid.Text([("highlight", "Bot \N{robot face}")])
             yield urwid.Divider()
         if account["locked"]:
             yield urwid.Text([("warning", "Locked \N{lock}")])
@@ -273,25 +300,28 @@ class Account(urwid.ListBox):
             yield urwid.Text([("warning", "Suspended \N{cross mark}")])
             yield urwid.Divider()
         if relationship["followed_by"]:
-            yield urwid.Text(("green", "Follows you \N{busts in silhouette}"))
+            yield urwid.Text(("highlight", "Follows you \N{busts in silhouette}"))
             yield urwid.Divider()
         if relationship["blocked_by"]:
             yield urwid.Text(("warning", "Blocks you \N{no entry}"))
             yield urwid.Divider()
 
-        yield urwid.Text(["Followers: ", ("yellow", f"{account['followers_count']}")])
-        yield urwid.Text(["Following: ", ("yellow", f"{account['following_count']}")])
-        yield urwid.Text(["Statuses: ", ("yellow", f"{account['statuses_count']}")])
+        yield urwid.Text(["Followers: ", ("highlight", f"{account['followers_count']}")])
+        yield urwid.Text(["Following: ", ("highlight", f"{account['following_count']}")])
+        yield urwid.Text(["Statuses: ", ("highlight", f"{account['statuses_count']}")])
 
         if account["fields"]:
             for field in account["fields"]:
                 name = field["name"].title()
                 yield urwid.Divider()
-                yield urwid.Text([("yellow", f"{name.rstrip(':')}"), ":"])
-                for line in format_content(field["value"]):
-                    yield urwid.Text(highlight_hashtags(line, followed_tags=set()))
+                yield urwid.Text([("bold", f"{name.rstrip(':')}"), ":"])
+
+                widgetlist = html_to_widgets(field["value"])
+                for line in widgetlist:
+                    yield (line)
+
                 if field["verified_at"]:
-                    yield urwid.Text(("green", "✓ Verified"))
+                    yield urwid.Text(("success", "✓ Verified"))
 
         yield urwid.Divider()
         yield link("", account["url"])
@@ -301,17 +331,17 @@ def take_action(button: Button, self: Account):
     action = button.get_label()
 
     if action == "Confirm Follow":
-        self.relationship = api.follow(self.app, self.user, self.account["id"])
+        self.relationship = api.follow(self.app, self.user, self.account["id"]).json()
     elif action == "Confirm Unfollow":
-        self.relationship = api.unfollow(self.app, self.user, self.account["id"])
+        self.relationship = api.unfollow(self.app, self.user, self.account["id"]).json()
     elif action == "Confirm Mute":
-        self.relationship = api.mute(self.app, self.user, self.account["id"])
+        self.relationship = api.mute(self.app, self.user, self.account["id"]).json()
     elif action == "Confirm Unmute":
-        self.relationship = api.unmute(self.app, self.user, self.account["id"])
+        self.relationship = api.unmute(self.app, self.user, self.account["id"]).json()
     elif action == "Confirm Block":
-        self.relationship = api.block(self.app, self.user, self.account["id"])
+        self.relationship = api.block(self.app, self.user, self.account["id"]).json()
     elif action == "Confirm Unblock":
-        self.relationship = api.unblock(self.app, self.user, self.account["id"])
+        self.relationship = api.unblock(self.app, self.user, self.account["id"]).json()
 
     self.last_action = None
     self.setup_listbox()
